/* expand.h -- Functions to expand % escapes in strings. */
/* $Id: expand.h 204 2005-10-12 22:34:59Z rra $ */

#ifndef H_EXPAND
#define H_EXPAND

#include <sys/types.h>

/* Expand a format string that contains % escapes, returning a pointer to
   the result or NULL in the event of any failure.  The format string looks
   a bit like a printf() format string, and takes the following special %
   sequences:

       %%   A literal '%' character.
       %d   A date, formatted as yyyy-mm-dd, from the time_t passed in.
       %D   The two-digit current day of the month.
       %M   The two-digit current month of the year (January being 01).
       %Y   The four-digit current year.
       %m   The machine name, truncated at the first period.
       %n   An arbitrary string, from the char * passed in.
       %s   An arbitrary string from the variable arguments section.
       %t   Seconds since epoch (a Unix timestamp).

   If there are no %n and %d escapes in the format string, name and date are
   not used. */
extern char *expand(const char *format, const char *name, time_t date, ...);

#endif /* H_EXPAND */
