/* utility.h -- Utility functions. */
/* $Id: utility.h 156 2004-02-01 22:30:36Z eagle $ */

#ifndef H_UTILITY
#define H_UTILITY

#include <stdarg.h>             /* va_list */
#include <sys/types.h>          /* size_t */

/* Error handling function prototypes. */
extern void warn(const char *, ...)
    __attribute__((__format__(printf, 1, 2)));
extern void syswarn(const char *, ...)
    __attribute__((__format__(printf, 1, 2)));
extern void die(const char *, ...)
    __attribute__((__noreturn__, __format__(printf, 1, 2)));
extern void sysdie(const char *, ...)
    __attribute__((__noreturn__, __format__(printf, 1, 2)));
extern void warn_set_handlers(int count, ...);
extern void die_set_handlers(int count, ...);

/* Handlers intended to be passed to *_set_handlers.  error_log_stderr is
   the only handler enabled by default. */
extern void error_log_stderr(int, const char *, va_list, int);
extern void error_log_syslog_err(int, const char *, va_list, int);
extern void error_log_syslog_warning(int, const char *, va_list, int);

/* Log handling functions take the length of the resulting message, the
   format, the arguments, and the errno if any. */
typedef void (*error_handler_t)(int, const char *, va_list, int);

/* Failure handler takes the function, the size, the file, and the line. */
typedef void (*xmalloc_handler_t)(const char *, size_t, const char *, int);

/* If non-NULL, called before exit and its return value passed to exit. */
extern int (*error_fatal_cleanup)(void);

/* If non-NULL, prepended (followed by ": ") to all error messages. */
extern const char *error_program_name;

/* The xmalloc, xrealloc, and xstrdup functions are actually macros so that
   we can pick up the file and line number information for debugging error
   messages without the user having to pass those in every time. */
#define xmalloc(size)           x_malloc((size), __FILE__, __LINE__)
#define xrealloc(p, size)       x_realloc((p), (size), __FILE__, __LINE__)
#define xstrdup(p)              x_strdup((p), __FILE__, __LINE__)

/* Last two arguments are always file and line number.  These are internal
   implementations that should not be called directly.  ISO C99 says that
   identifiers beginning with _ and a lowercase letter are reserved for
   identifiers of file scope, so while the position of libraries in the
   standard isn't clear, it's probably not entirely kosher to use _xmalloc
   here.  Use x_malloc instead. */
extern void *x_malloc(size_t, const char *, int);
extern void *x_realloc(void *, size_t, const char *, int);
extern char *x_strdup(const char *, const char *, int);

/* Assign to this variable to choose a handler other than the default, which
   just calls sysdie. */
extern xmalloc_handler_t xmalloc_error_handler;

/* Print a usage message and exit with the given exit status. */
extern void usage(int status) __attribute__((__noreturn__));

#endif /* H_UTILITY */
